[![Supported Python Versions](https://img.shields.io/pypi/pyversions/dahlia)](https://pypi.python.org/pypi/dahlia)
[![PyPI version](https://badge.fury.io/py/dahlia.svg)](https://badge.fury.io/py/dahlia)
[![Documentation Status](https://readthedocs.org/projects/dahlia/badge/?version=latest)](https://dahlia.readthedocs.io/en/latest/?badge=latest)
# Dahlia

Dahlia is a simple text formatting package, inspired by text formatting in the game Minecraft.

Text is formatted in a similar way to in the game. With Dahlia, it is formatted by typing a special character `&` followed by a format code and finally the text to be formatted.

## Installation

Dahlia is available on PyPI and can be installed with pip, or any other Python package manager:

```
$ pip install dahlia
```
(Some systems may require you to use `pip3`, `python -m pip`, or `py -m pip` instead)

## Documentation

Dahlia documentation is available at https://dahlia.readthedocs.io.

## License

Dahlia is licensed under the MIT License.

## Examples

<img width="805" alt="Screen Shot 2022-10-05 at 22 56 57" src="https://user-images.githubusercontent.com/77130613/194162110-fb77713c-7008-4f5f-a79c-7a3666f2fd11.png">
